@@ -21,6 +21,8 @@ from cryspy_editor.widgets.w_pd_meas import w_for_pd_meas
 from cryspy_editor.widgets.w_pd_proc import w_for_pd_proc
 from pycifstar import Data, Global, Item, Items, Loop, to_global
 
+from cryspy_editor.widgets.w_item import w_for_item
+
 try:
     FLAG_CRYSPY = True
     from cryspy_editor.widgets.FUNCTIONS import del_layout
@@ -65,6 +67,7 @@ except ImportError:
 class MyThread(QtCore.QThread):
     signal_start = QtCore.pyqtSignal()
     signal_end = QtCore.pyqtSignal()
+    signal_refresh = QtCore.pyqtSignal()
 
     def __init__(self, parent=None):
         QtCore.QThread.__init__(self, parent)
@@ -397,6 +400,7 @@ class cwidget(QtWidgets.QSplitter):
         self._object = None
         self.additional_thread = MyThread()
         self.additional_thread.signal_end.connect(self.end_of_calc_in_thread)
+        self.additional_thread.signal_refresh.connect(self.refresh_wind)
         self.additional_thread.signal_start.connect(
             self.start_of_calc_in_thread)
         self.init_widget()
@@ -500,7 +504,7 @@ class cwidget(QtWidgets.QSplitter):
         if obj is None:
             obj = self._object
         if obj is not None:
-
+            self._object = obj 
             w1 = QtWidgets.QTreeWidget()
             w1.setSizePolicy(QtWidgets.QSizePolicy(
                 QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding))
@@ -683,7 +687,8 @@ class cwidget(QtWidgets.QSplitter):
             elif isinstance(obj, Loop):
                 pass
             elif isinstance(obj, Item):
-                pass
+                w_for_item(obj, layout_11, layout_12,
+                           layout_13, layout_2, layout_3, w_output, thread)
 
     def start_of_calc_in_thread(self):
         self.w_loader.setChecked(True)
@@ -707,6 +712,9 @@ class cwidget(QtWidgets.QSplitter):
         self.w_output.setText("\n".join(ls_out))
         self.form_cpanel()
 
+    def refresh_wind(self):
+        self.form_cpanel()
+
 
 def main_w(l_arg=[]):
     app = QtWidgets.QApplication(l_arg)
