@@ -20,6 +20,6 @@ def w_for_item_constr(obj, layout_11, layout_12, layout_13, layout_2, layout_3,
     layout_13.addLayout(lay_left_3)
 
 
-    _lay_3 = get_layout_rciftab_obj(obj)
+    _lay_3 = get_layout_rciftab_obj(obj, thread)
     layout_2.addLayout(_lay_3)
     return
